@@ -10,10 +10,9 @@ testthat::skip_on_cran()
 test_that("read_municipal_seat", {
 
   # read data and check sf object
-  testthat::expect_output( read_municipal_seat() )
+  expect_true(is( read_municipal_seat(), "sf"))
+
   test_sf <- read_municipal_seat(year=1991)
-
-
   expect_true(is(test_sf, "sf"))
 
 })
